@@ -170,6 +170,13 @@
 #include "clutter-scriptable.h"
 #include "clutter-script-private.h"
 
+static void clutter_scriptable_iface_init (ClutterScriptableIface *iface);
+
+G_DEFINE_ABSTRACT_TYPE_WITH_CODE
+        (ClutterModel, clutter_model, G_TYPE_OBJECT,
+         G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_SCRIPTABLE,
+                                clutter_scriptable_iface_init));
+
 enum
 {
   PROP_0,
@@ -191,6 +198,9 @@ enum
 
 static guint model_signals[LAST_SIGNAL] = { 0, };
 
+#define CLUTTER_MODEL_GET_PRIVATE(obj) \
+  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CLUTTER_TYPE_MODEL, ClutterModelPrivate))
+
 struct _ClutterModelPrivate
 {
   GType                  *column_types;
@@ -216,20 +226,13 @@ struct _ClutterModelPrivate
   GDestroyNotify          sort_notify;
 };
 
-static void clutter_scriptable_iface_init (ClutterScriptableIface *iface);
-
-G_DEFINE_ABSTRACT_TYPE_WITH_CODE (ClutterModel, clutter_model, G_TYPE_OBJECT,
-                                  G_ADD_PRIVATE (ClutterModel)
-                                  G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_SCRIPTABLE,
-                                                         clutter_scriptable_iface_init))
-
 static GType
 clutter_model_real_get_column_type (ClutterModel *model,
                                     guint         column)
 {
   ClutterModelPrivate *priv = model->priv;
 
-  if (column >= clutter_model_get_n_columns (model))
+  if (column < 0 || column >= clutter_model_get_n_columns (model))
     return G_TYPE_INVALID;
 
   return priv->column_types[column];
@@ -241,7 +244,7 @@ clutter_model_real_get_column_name (ClutterModel *model,
 {
   ClutterModelPrivate *priv = model->priv;
 
-  if (column >= clutter_model_get_n_columns (model))
+  if (column < 0 || column >= clutter_model_get_n_columns (model))
     return NULL;
 
   if (priv->column_names && priv->column_names[column])
@@ -344,6 +347,8 @@ clutter_model_class_init (ClutterModelClass *klass)
   gobject_class->get_property = clutter_model_get_property;
   gobject_class->finalize = clutter_model_finalize;
 
+  g_type_class_add_private (gobject_class, sizeof (ClutterModelPrivate));
+
   klass->get_column_name  = clutter_model_real_get_column_name;
   klass->get_column_type  = clutter_model_real_get_column_type;
   klass->get_n_columns    = clutter_model_real_get_n_columns;
@@ -465,7 +470,7 @@ clutter_model_init (ClutterModel *self)
 {
   ClutterModelPrivate *priv;
   
-  self->priv = priv = clutter_model_get_instance_private (self);
+  self->priv = priv = CLUTTER_MODEL_GET_PRIVATE (self);
 
   priv->n_columns = -1;
   priv->column_types = NULL;
@@ -485,7 +490,7 @@ clutter_model_init (ClutterModel *self)
  * type.
  */
 gboolean
-_clutter_model_check_type (GType gtype)
+clutter_model_check_type (GType gtype)
 {
   gint i = 0;
   static const GType type_list[] =
@@ -620,14 +625,14 @@ clutter_model_set_custom_property (ClutterScriptable *scriptable,
       columns = g_value_get_pointer (value);
       n_columns = g_slist_length (columns);
 
-      _clutter_model_set_n_columns (model, n_columns, TRUE, TRUE);
+      clutter_model_set_n_columns (model, n_columns, TRUE, TRUE);
 
       for (i = 0, l = columns; l != NULL; l = l->next, i++)
         {
           ColumnInfo *cinfo = l->data;
 
-          _clutter_model_set_column_name (model, i, cinfo->name);
-          _clutter_model_set_column_type (model, i, cinfo->type);
+          clutter_model_set_column_name (model, i, cinfo->name);
+          clutter_model_set_column_type (model, i, cinfo->type);
 
           g_free (cinfo->name);
           g_slice_free (ColumnInfo, cinfo);
@@ -647,41 +652,39 @@ clutter_model_set_custom_property (ClutterScriptable *scriptable,
       for (l = rows; l; l = l->next)
         {
           JsonNode *node = l->data;
-          guint *columns = NULL, i, n_values = 0;
-          GValue *values = NULL;
+          guint *columns, i, n_values = 0;
+          GValueArray *values;
 
           if (JSON_NODE_TYPE (node) == JSON_NODE_ARRAY)
             {
               JsonArray *array = json_node_get_array (node);
-
               if (json_array_get_length (array) != n_columns)
                 {
                   g_warning ("Row %d contains the wrong count of columns",
                              g_slist_position (rows, l) + 1);
-                  row += 1;
+                  row++;
                   continue;
                 }
 
-              /* array more requires all columns */
               n_values = n_columns;
-
               columns = g_new (guint, n_values);
-              values = g_new0 (GValue, n_values);
+              values = g_value_array_new (n_values);
 
               for (i = 0; i < n_values; i++)
                 {
                   GType column_type;
                   const gchar *column_name;
+                  GValue v = { 0, };
 
                   column_type = clutter_model_get_column_type (model, i);
                   column_name = clutter_model_get_column_name (model, i);
-
                   columns[i] = i;
-                  g_value_init (&values[i], column_type);
-
-                  _clutter_script_parse_node (script, &values[i], column_name,
-                                              json_array_get_element (array, i),
-                                              NULL);
+                  g_value_init (&v, column_type);
+                  clutter_script_parse_node (script, &v, column_name,
+                                             json_array_get_element (array, i),
+                                             NULL);
+                  g_value_array_append (values, &v);
+                  g_value_unset (&v);
                 }
             }
           else if (JSON_NODE_TYPE (node) == JSON_NODE_OBJECT)
@@ -690,11 +693,9 @@ clutter_model_set_custom_property (ClutterScriptable *scriptable,
               GList *members, *m;
               guint column = 0;
 
-              /* object mode does not require all columns */
               n_values = json_object_get_size (object);
-
               columns = g_new (guint, n_values);
-              values = g_new0 (GValue, n_values);
+              values = g_value_array_new (n_values);
 
               members = json_object_get_members (object);
               for (m = members; m; m = m->next)
@@ -711,38 +712,35 @@ clutter_model_set_custom_property (ClutterScriptable *scriptable,
                           JsonNode *member;
                           GType col_type;
                           const gchar *col_name;
-
-                          member = json_object_get_member (object, mname);
+                          GValue v = { 0, };
 
                           col_type = clutter_model_get_column_type (model, i);
                           col_name = clutter_model_get_column_name (model, i);
-
                           columns[column] = i;
-                          g_value_init (&values[column], col_type);
-
-                          _clutter_script_parse_node (script, &values[column],
-                                                      col_name, member,
-                                                      NULL);
+                          g_value_init (&v, col_type);
+                          member = json_object_get_member (object, mname);
+                          clutter_script_parse_node (script, &v,
+                                                     col_name, member,
+                                                     NULL);
+                          g_value_array_append (values, &v);
+                          g_value_unset (&v);
                           break;
                         }
                     }
-
-                  column += 1;
+                  column++;
                 }
             }
           else
             {
-              row += 1;
+              row++;
               continue;
             }
 
-          clutter_model_insertv (model, row, n_values, columns, values);
-
-          g_free (values);
+          clutter_model_insertv (model, row, n_values, columns, values->values);
+          g_value_array_free (values);
           g_free (columns);
           json_node_free (node);
-
-          row += 1;
+          row++;
         }
       g_slist_free (rows);
     }
@@ -853,7 +851,7 @@ clutter_model_filter_iter (ClutterModel     *model,
   return priv->filter_func (model, iter, priv->filter_data);
 }
 
-/*< private >
+/*
  * clutter_model_set_n_columns:
  * @model: a #ClutterModel
  * @n_columns: number of columns
@@ -867,10 +865,10 @@ clutter_model_filter_iter (ClutterModel     *model,
  * This function can only be called once.
  */
 void
-_clutter_model_set_n_columns (ClutterModel *model,
-                              gint          n_columns,
-                              gboolean      set_types,
-                              gboolean      set_names)
+clutter_model_set_n_columns (ClutterModel *model,
+                             gint          n_columns,
+                             gboolean      set_types,
+                             gboolean      set_names)
 {
   ClutterModelPrivate *priv = model->priv;
 
@@ -886,8 +884,8 @@ _clutter_model_set_n_columns (ClutterModel *model,
     priv->column_names = g_new0 (gchar*, n_columns);
 }
 
-/*< private >
- * _clutter_model_set_column_type:
+/*
+ * clutter_model_set_column_type:
  * @model: a #ClutterModel
  * @column: column index
  * @gtype: type of the column
@@ -895,17 +893,17 @@ _clutter_model_set_n_columns (ClutterModel *model,
  * Sets the type of @column inside @model
  */
 void
-_clutter_model_set_column_type (ClutterModel *model,
-                                gint          column,
-                                GType         gtype)
+clutter_model_set_column_type (ClutterModel *model,
+                               gint          column,
+                               GType         gtype)
 {
   ClutterModelPrivate *priv = model->priv;
 
   priv->column_types[column] = gtype;
 }
 
-/*< private >
- * _clutter_model_set_column_name:
+/*
+ * clutter_model_set_column_name:
  * @model: a #ClutterModel
  * @column: column index
  * @name: name of the column, or %NULL
@@ -913,9 +911,9 @@ _clutter_model_set_column_type (ClutterModel *model,
  * Sets the name of @column inside @model
  */
 void
-_clutter_model_set_column_name (ClutterModel *model,
-                                gint          column,
-                                const gchar  *name)
+clutter_model_set_column_name (ClutterModel *model,
+                               gint          column,
+                               const gchar  *name)
 {
   ClutterModelPrivate *priv = model->priv;
 
@@ -952,17 +950,17 @@ clutter_model_set_types (ClutterModel *model,
   g_return_if_fail (priv->n_columns < 0 || priv->n_columns == n_columns);
   g_return_if_fail (priv->column_types == NULL);
 
-  _clutter_model_set_n_columns (model, n_columns, TRUE, FALSE);
+  clutter_model_set_n_columns (model, n_columns, TRUE, FALSE);
 
   for (i = 0; i < n_columns; i++)
     {
-      if (!_clutter_model_check_type (types[i]))
+      if (!clutter_model_check_type (types[i]))
         {
           g_warning ("%s: Invalid type %s\n", G_STRLOC, g_type_name (types[i]));
           return;
         }
 
-      _clutter_model_set_column_type (model, i, types[i]);
+      clutter_model_set_column_type (model, i, types[i]);
     }
 }
 
@@ -996,10 +994,10 @@ clutter_model_set_names (ClutterModel        *model,
   g_return_if_fail (priv->n_columns < 0 || priv->n_columns == n_columns);
   g_return_if_fail (priv->column_names == NULL);
 
-  _clutter_model_set_n_columns (model, n_columns, FALSE, TRUE);
+  clutter_model_set_n_columns (model, n_columns, FALSE, TRUE);
 
   for (i = 0; i < n_columns; i++)
-    _clutter_model_set_column_name (model, i, names[i]);
+    clutter_model_set_column_name (model, i, names[i]);
 }
 
 /**
@@ -1076,7 +1074,7 @@ static void clutter_model_iter_set_internal_valist (ClutterModelIter *iter,
 /**
  * clutter_model_append:
  * @model: a #ClutterModel
- * @...: pairs of column number and value, terminated with -1
+ * @Varargs: pairs of column number and value, terminated with -1
  *
  * Creates and appends a new row to the #ClutterModel, setting the
  * row values upon creation. For example, to append a new row where
@@ -1166,7 +1164,7 @@ clutter_model_prependv (ClutterModel *model,
 /**
  * clutter_model_prepend:
  * @model: a #ClutterModel
- * @...: pairs of column number and value, terminated with -1
+ * @Varargs: pairs of column number and value, terminated with -1
  *
  * Creates and prepends a new row to the #ClutterModel, setting the row
  * values upon creation. For example, to prepend a new row where column 0
@@ -1208,7 +1206,7 @@ clutter_model_prepend (ClutterModel *model,
  * clutter_model_insert:
  * @model: a #ClutterModel
  * @row: the position to insert the new row
- * @...: pairs of column number and value, terminated with -1
+ * @Varargs: pairs of column number and value, terminated with -1
  *
  * Inserts a new row to the #ClutterModel at @row, setting the row
  * values upon creation. For example, to insert a new row at index 100,
@@ -1392,7 +1390,7 @@ clutter_model_get_column_name (ClutterModel *model,
 
   g_return_val_if_fail (CLUTTER_IS_MODEL (model), NULL);
 
-  if (column >= clutter_model_get_n_columns (model))
+  if (column < 0 || column >= clutter_model_get_n_columns (model))
     {
       g_warning ("%s: Invalid column id value %d\n", G_STRLOC, column);
       return NULL;
@@ -1424,7 +1422,7 @@ clutter_model_get_column_type (ClutterModel *model,
 
   g_return_val_if_fail (CLUTTER_IS_MODEL (model), G_TYPE_INVALID);
 
-  if (column >= clutter_model_get_n_columns (model))
+  if (column < 0 || column >= clutter_model_get_n_columns (model))
     {
       g_warning ("%s: Invalid column id value %d\n", G_STRLOC, column);
       return G_TYPE_INVALID;
@@ -1752,14 +1750,20 @@ clutter_model_get_filter_set (ClutterModel *model)
  * #ClutterModelIter is available since Clutter 0.6
  */
 
+G_DEFINE_ABSTRACT_TYPE (ClutterModelIter, clutter_model_iter, G_TYPE_OBJECT);
+
+#define CLUTTER_MODEL_ITER_GET_PRIVATE(obj) \
+  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
+  CLUTTER_TYPE_MODEL_ITER, ClutterModelIterPrivate))
+
 struct _ClutterModelIterPrivate
 {
   ClutterModel  *model;
 
   gint row;
-};
 
-G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (ClutterModelIter, clutter_model_iter, G_TYPE_OBJECT)
+  guint ignore_sort : 1;
+};
 
 enum
 {
@@ -1783,8 +1787,8 @@ clutter_model_iter_real_get_row (ClutterModelIter *iter)
 
 /* private function */
 void
-_clutter_model_iter_set_row (ClutterModelIter *iter,
-                             guint             row)
+clutter_model_iter_set_row (ClutterModelIter *iter,
+                            guint             row)
 {
   iter->priv->row = row;
 }
@@ -1955,56 +1959,60 @@ clutter_model_iter_class_init (ClutterModelIterClass *klass)
                              0, G_MAXUINT, 0,
                              CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class, ITER_PROP_ROW, pspec);
+  
+  g_type_class_add_private (gobject_class, sizeof (ClutterModelIterPrivate));
 }
 
 static void
 clutter_model_iter_init (ClutterModelIter *self)
 {
-  self->priv = clutter_model_iter_get_instance_private (self);
+  ClutterModelIterPrivate *priv;
+  
+  self->priv = priv = CLUTTER_MODEL_ITER_GET_PRIVATE (self);
+
+  priv->model = NULL;
+  priv->row = 0;
+
+  priv->ignore_sort = FALSE;
 }
 
 /*
  *  Public functions
  */
 
-static inline void
-clutter_model_iter_set_value_internal (ClutterModelIter *iter,
-                                       guint             column,
-                                       const GValue     *value)
-{
-  CLUTTER_MODEL_ITER_GET_CLASS (iter)->set_value (iter, column, value);
-}
-
 static void
 clutter_model_iter_set_internal_valist (ClutterModelIter *iter,
                                         va_list           args)
 {
-  ClutterModelIterPrivate *priv = iter->priv;
-  ClutterModel *model = priv->model;
+  ClutterModel *model;
+  ClutterModelIterPrivate *priv;
   guint column = 0;
   gboolean sort = FALSE;
   
+  priv = iter->priv;
+  model = priv->model;
   g_assert (CLUTTER_IS_MODEL (model));
 
   column = va_arg (args, gint);
   
+  /* Don't want to sort while setting lots of fields, leave that till the end
+   */
+  priv->ignore_sort = TRUE;
   while (column != -1)
     {
-      GValue value = G_VALUE_INIT;
+      GValue value = { 0, };
       gchar *error = NULL;
-      GType col_type;
 
-      if (column >= clutter_model_get_n_columns (model))
+      if (column < 0 || column >= clutter_model_get_n_columns (model))
         { 
           g_warning ("%s: Invalid column number %d added to iter "
                      "(remember to end you list of columns with a -1)",
                      G_STRLOC, column);
           break;
         }
+      g_value_init (&value, clutter_model_get_column_type (model, column));
 
-      col_type = clutter_model_get_column_type (model, column);
-
-      G_VALUE_COLLECT_INIT (&value, col_type, args, 0, &error);
+      G_VALUE_COLLECT (&value, args, 0, &error);
       if (error)
         {
           g_warning ("%s: %s", G_STRLOC, error);
@@ -2014,7 +2022,7 @@ clutter_model_iter_set_internal_valist (ClutterModelIter *iter,
           break;
         }
 
-      clutter_model_iter_set_value_internal (iter, column, &value);
+      clutter_model_iter_set_value (iter, column, &value);
       
       g_value_unset (&value);
       
@@ -2024,21 +2032,11 @@ clutter_model_iter_set_internal_valist (ClutterModelIter *iter,
       column = va_arg (args, gint);
     }
 
+  priv->ignore_sort = FALSE;
   if (sort)
     clutter_model_resort (model);
 }
 
-static void inline
-clutter_model_iter_emit_row_changed (ClutterModelIter *iter)
-{
-  ClutterModelIterPrivate *priv = iter->priv;
-  ClutterModel *model = priv->model;
-
-  g_assert (CLUTTER_IS_MODEL (model));
-
-  g_signal_emit (model, model_signals[ROW_CHANGED], 0, iter);
-}
-
 /**
  * clutter_model_iter_set_valist:
  * @iter: a #ClutterModelIter
@@ -2053,16 +2051,24 @@ void
 clutter_model_iter_set_valist (ClutterModelIter *iter,
                                va_list           args)
 {
+  ClutterModelIterPrivate *priv;
+  ClutterModel *model;
+
   g_return_if_fail (CLUTTER_IS_MODEL_ITER (iter));
 
   clutter_model_iter_set_internal_valist (iter, args);
-  clutter_model_iter_emit_row_changed (iter);
+
+  priv = iter->priv;
+  model = priv->model;
+  g_assert (CLUTTER_IS_MODEL (model));
+
+  g_signal_emit (model, model_signals[ROW_CHANGED], 0, iter);
 }
 
 /**
  * clutter_model_iter_get:
  * @iter: a #ClutterModelIter
- * @...: a list of column/return location pairs, terminated by -1
+ * @Varargs: a list of column/return location pairs, terminated by -1
  *
  * Gets the value of one or more cells in the row referenced by @iter. The
  * variable argument list should contain integer column numbers, each column
@@ -2092,14 +2098,6 @@ clutter_model_iter_get (ClutterModelIter *iter,
   va_end (args);
 }
 
-static inline void
-clutter_model_iter_get_value_internal (ClutterModelIter *iter,
-                                       guint             column,
-                                       GValue           *value)
-{
-  CLUTTER_MODEL_ITER_GET_CLASS (iter)->get_value (iter, column, value);
-}
-
 /**
  * clutter_model_iter_get_value:
  * @iter: a #ClutterModelIter
@@ -2116,16 +2114,18 @@ clutter_model_iter_get_value (ClutterModelIter *iter,
                               guint             column,
                               GValue           *value)
 {
+  ClutterModelIterClass *klass;
   ClutterModel *model;
 
   g_return_if_fail (CLUTTER_IS_MODEL_ITER (iter));
   
   model = iter->priv->model;
 
-  if (G_VALUE_TYPE (value) == G_TYPE_INVALID)
-    g_value_init (value, clutter_model_get_column_type (model, column));
+  g_value_init (value, clutter_model_get_column_type (model, column));
 
-  CLUTTER_MODEL_ITER_GET_CLASS (iter)->get_value (iter, column, value);
+  klass = CLUTTER_MODEL_ITER_GET_CLASS (iter);
+  if (klass && klass->get_value)
+    klass->get_value (iter, column, value);
 }
 
 /**
@@ -2156,11 +2156,10 @@ clutter_model_iter_get_valist (ClutterModelIter *iter,
 
   while (column != -1)
     {
-      GValue value = G_VALUE_INIT;
+      GValue value = { 0, };
       gchar *error = NULL;
-      GType col_type;
 
-      if (column >= clutter_model_get_n_columns (model))
+      if (column < 0 || column >= clutter_model_get_n_columns (model))
         { 
           g_warning ("%s: Invalid column number %d added to iter "
                      "(remember to end you list of columns with a -1)",
@@ -2168,10 +2167,10 @@ clutter_model_iter_get_valist (ClutterModelIter *iter,
           break;
         }
 
-      col_type = clutter_model_get_column_type (model, column);
-      g_value_init (&value, col_type);
-
-      clutter_model_iter_get_value_internal (iter, column, &value);
+      /* this one will take care of initialising value to the
+       * correct type
+       */
+      clutter_model_iter_get_value (iter, column, &value);
 
       G_VALUE_LCOPY (&value, args, 0, &error);
       if (error)
@@ -2192,7 +2191,7 @@ clutter_model_iter_get_valist (ClutterModelIter *iter,
 /**
  * clutter_model_iter_set:
  * @iter: a #ClutterModelIter
- * @...: a list of column/return location pairs, terminated by -1
+ * @Varargs: a list of column/return location pairs, terminated by -1
  *
  * Sets the value of one or more cells in the row referenced by @iter. The
  * variable argument list should contain integer column numbers, each column
@@ -2215,11 +2214,11 @@ clutter_model_iter_set (ClutterModelIter *iter,
   g_return_if_fail (CLUTTER_IS_MODEL_ITER (iter));
 
   va_start (args, iter);
-  clutter_model_iter_set_internal_valist (iter, args);
-  clutter_model_iter_emit_row_changed (iter);
+  clutter_model_iter_set_valist (iter, args);
   va_end (args);
 }
 
+
 /**
  * clutter_model_iter_set_value:
  * @iter: a #ClutterModelIter
@@ -2236,10 +2235,13 @@ clutter_model_iter_set_value (ClutterModelIter *iter,
                               guint             column,
                               const GValue     *value)
 {
-  g_return_if_fail (CLUTTER_IS_MODEL_ITER (iter));
+  ClutterModelIterClass *klass;
 
-  clutter_model_iter_set_value_internal (iter, column, value);
-  clutter_model_iter_emit_row_changed (iter);
+  g_return_if_fail (CLUTTER_IS_MODEL_ITER (iter));
+  
+  klass = CLUTTER_MODEL_ITER_GET_CLASS (iter);
+  if (klass && klass->set_value)
+    klass->set_value (iter, column, value);
 }
 
 /**
@@ -2256,9 +2258,15 @@ clutter_model_iter_set_value (ClutterModelIter *iter,
 gboolean
 clutter_model_iter_is_first (ClutterModelIter *iter)
 {
+  ClutterModelIterClass *klass;
+
   g_return_val_if_fail (CLUTTER_IS_MODEL_ITER (iter), FALSE);
   
-  return CLUTTER_MODEL_ITER_GET_CLASS (iter)->is_first (iter);
+  klass = CLUTTER_MODEL_ITER_GET_CLASS (iter);
+  if (klass && klass->is_first)
+    return klass->is_first (iter);
+
+  return FALSE;
 }
 
 /**
@@ -2275,9 +2283,15 @@ clutter_model_iter_is_first (ClutterModelIter *iter)
 gboolean
 clutter_model_iter_is_last (ClutterModelIter *iter)
 {
+  ClutterModelIterClass *klass;
+
   g_return_val_if_fail (CLUTTER_IS_MODEL_ITER (iter), FALSE);
   
-  return CLUTTER_MODEL_ITER_GET_CLASS (iter)->is_last (iter);
+  klass = CLUTTER_MODEL_ITER_GET_CLASS (iter);
+  if (klass && klass->is_last)
+    return klass->is_last (iter);
+
+  return FALSE;
 }
 
 /**
@@ -2296,9 +2310,15 @@ clutter_model_iter_is_last (ClutterModelIter *iter)
 ClutterModelIter *
 clutter_model_iter_next (ClutterModelIter *iter)
 {
+  ClutterModelIterClass *klass;
+
   g_return_val_if_fail (CLUTTER_IS_MODEL_ITER (iter), NULL);
   
-  return CLUTTER_MODEL_ITER_GET_CLASS (iter)->next (iter);
+  klass = CLUTTER_MODEL_ITER_GET_CLASS (iter);
+  if (klass && klass->next)
+    return klass->next (iter);
+
+  return NULL;
 }
 
 /**
@@ -2317,9 +2337,15 @@ clutter_model_iter_next (ClutterModelIter *iter)
 ClutterModelIter *
 clutter_model_iter_prev (ClutterModelIter *iter)
 {
+  ClutterModelIterClass *klass;
+
   g_return_val_if_fail (CLUTTER_IS_MODEL_ITER (iter), NULL);
   
-  return CLUTTER_MODEL_ITER_GET_CLASS (iter)->prev (iter);
+  klass = CLUTTER_MODEL_ITER_GET_CLASS (iter);
+  if (klass && klass->prev)
+    return klass->prev (iter);
+
+  return NULL;
 }
 
 /**
@@ -2335,9 +2361,15 @@ clutter_model_iter_prev (ClutterModelIter *iter)
 ClutterModel *
 clutter_model_iter_get_model (ClutterModelIter *iter)
 {
+  ClutterModelIterClass *klass;
+
   g_return_val_if_fail (CLUTTER_IS_MODEL_ITER (iter), NULL);
   
-  return CLUTTER_MODEL_ITER_GET_CLASS (iter)->get_model (iter);
+  klass = CLUTTER_MODEL_ITER_GET_CLASS (iter);
+  if (klass && klass->get_model)
+    return klass->get_model (iter);
+
+  return NULL;
 }
 
 /**
@@ -2353,9 +2385,15 @@ clutter_model_iter_get_model (ClutterModelIter *iter)
 guint
 clutter_model_iter_get_row (ClutterModelIter *iter)
 {
+  ClutterModelIterClass *klass;
+
   g_return_val_if_fail (CLUTTER_IS_MODEL_ITER (iter), 0);
   
-  return CLUTTER_MODEL_ITER_GET_CLASS (iter)->get_row (iter);
+  klass = CLUTTER_MODEL_ITER_GET_CLASS (iter);
+  if (klass && klass->get_row)
+    return klass->get_row (iter);
+
+  return 0;
 }
 
 /**
@@ -2371,7 +2409,13 @@ clutter_model_iter_get_row (ClutterModelIter *iter)
 ClutterModelIter *
 clutter_model_iter_copy (ClutterModelIter *iter)
 {
+  ClutterModelIterClass *klass;
+
   g_return_val_if_fail (CLUTTER_IS_MODEL_ITER (iter), NULL);
 
-  return CLUTTER_MODEL_ITER_GET_CLASS (iter)->copy (iter);
+  klass = CLUTTER_MODEL_ITER_GET_CLASS (iter);
+  if (klass->copy)
+    return klass->copy (iter);
+
+  return NULL;
 }
