@@ -40,13 +40,11 @@
 #include "clutter-layout-manager.h"
 #include "clutter-master-clock.h"
 #include "clutter-settings.h"
-#include "clutter-stage-manager.h"
 #include "clutter-stage.h"
 
 G_BEGIN_DECLS
 
 typedef struct _ClutterMainContext      ClutterMainContext;
-typedef struct _ClutterVertex4          ClutterVertex4;
 
 #define CLUTTER_REGISTER_VALUE_TRANSFORM_TO(TYPE_TO,func)             { \
   g_value_register_transform_func (g_define_type_id, TYPE_TO, func);    \
@@ -70,13 +68,12 @@ typedef struct _ClutterVertex4          ClutterVertex4;
 #define CLUTTER_ACTOR_IN_REPARENT(a)            ((CLUTTER_PRIVATE_FLAGS (a) & CLUTTER_IN_REPARENT) != FALSE)
 #define CLUTTER_ACTOR_IN_PAINT(a)               ((CLUTTER_PRIVATE_FLAGS (a) & CLUTTER_IN_PAINT) != FALSE)
 #define CLUTTER_ACTOR_IN_RELAYOUT(a)            ((CLUTTER_PRIVATE_FLAGS (a) & CLUTTER_IN_RELAYOUT) != FALSE)
+#define CLUTTER_STAGE_IN_RESIZE(a)              ((CLUTTER_PRIVATE_FLAGS (a) & CLUTTER_IN_RESIZE) != FALSE)
 
 #define CLUTTER_PARAM_READABLE  (G_PARAM_READABLE | G_PARAM_STATIC_STRINGS)
 #define CLUTTER_PARAM_WRITABLE  (G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS)
 #define CLUTTER_PARAM_READWRITE (G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS)
 
-#define CLUTTER_PARAM_ANIMATABLE        (1 << G_PARAM_USER_SHIFT)
-
 /* automagic interning of a static string */
 #define I_(str)  (g_intern_static_string ((str)))
 
@@ -87,13 +84,6 @@ typedef struct _ClutterVertex4          ClutterVertex4;
 #define P_(String) (String)
 #endif
 
-/* This is a replacement for the nearbyint function which always rounds to the
- * nearest integer. nearbyint is apparently a C99 function so it might not
- * always be available but also it seems in glibc it is defined as a function
- * call so this macro could end up faster anyway. We can't just add 0.5f
- * because it will break for negative numbers. */
-#define CLUTTER_NEARBYINT(x) ((int) ((x) < 0.0f ? (x) - 0.5f : (x) + 0.5f))
-
 typedef enum {
   CLUTTER_ACTOR_UNUSED_FLAG = 0,
 
@@ -107,8 +97,14 @@ typedef enum {
   /* Used to avoid recursion */
   CLUTTER_IN_RELAYOUT    = 1 << 4,
 
-  /* a flag for internal children of Containers (DEPRECATED) */
-  CLUTTER_INTERNAL_CHILD = 1 << 5
+  /* Used by the stage if resizing is an asynchronous operation (like on
+   * X11) to delay queueing relayouts until we got a notification from the
+   * event handling
+   */
+  CLUTTER_IN_RESIZE      = 1 << 5,
+
+  /* a flag for internal children of Containers */
+  CLUTTER_INTERNAL_CHILD = 1 << 6
 } ClutterPrivateFlags;
 
 /*
@@ -121,18 +117,11 @@ struct _ClutterMainContext
   /* the main windowing system backend */
   ClutterBackend *backend;
 
-  /* the object holding all the stage instances */
-  ClutterStageManager *stage_manager;
-
-  /* the clock driving all the frame operations */
-  ClutterMasterClock *master_clock;
-
   /* the main event queue */
   GQueue *events_queue;
 
-  /* the event filters added via clutter_event_add_filter. these are
-   * ordered from least recently added to most recently added */
-  GList *event_filters;
+  /* timer used to print the FPS count */
+  GTimer *timer;
 
   ClutterPickMode  pick_mode;
 
@@ -160,14 +149,13 @@ struct _ClutterMainContext
   PangoContext *pango_context;  /* Global Pango context */
   CoglPangoFontMap *font_map;   /* Global font map */
 
-  /* stack of #ClutterEvent */
-  GSList *current_event;
+  ClutterEvent *current_event;
+  guint32 last_event_time;
 
   /* list of repaint functions installed through
    * clutter_threads_add_repaint_func()
    */
   GList *repaint_funcs;
-  guint last_repaint_id;
 
   /* main settings singleton */
   ClutterSettings *settings;
@@ -177,7 +165,6 @@ struct _ClutterMainContext
   guint motion_events_per_actor : 1;
   guint defer_display_setup     : 1;
   guint options_parsed          : 1;
-  guint show_fps                : 1;
 };
 
 /* shared between clutter-main.c and clutter-frame-source.c */
@@ -191,12 +178,7 @@ typedef struct
 gboolean _clutter_threads_dispatch      (gpointer data);
 void     _clutter_threads_dispatch_free (gpointer data);
 
-void                    _clutter_threads_acquire_lock                   (void);
-void                    _clutter_threads_release_lock                   (void);
-
 ClutterMainContext *    _clutter_context_get_default                    (void);
-void                    _clutter_context_lock                           (void);
-void                    _clutter_context_unlock                         (void);
 gboolean                _clutter_context_is_initialized                 (void);
 PangoContext *          _clutter_context_create_pango_context           (void);
 PangoContext *          _clutter_context_get_pango_context              (void);
@@ -207,16 +189,11 @@ ClutterActor *          _clutter_context_peek_shader_stack              (void);
 guint32                 _clutter_context_acquire_id                     (gpointer      key);
 void                    _clutter_context_release_id                     (guint32       id_);
 gboolean                _clutter_context_get_motion_events_enabled      (void);
-gboolean                _clutter_context_get_show_fps                   (void);
 
 const gchar *_clutter_gettext (const gchar *str);
 
 gboolean      _clutter_feature_init (GError **error);
 
-/* Diagnostic mode */
-gboolean        _clutter_diagnostic_enabled     (void);
-void            _clutter_diagnostic_message     (const char *fmt, ...);
-
 /* Picking code */
 guint           _clutter_pixel_to_id            (guchar        pixel[4]);
 void            _clutter_id_to_color            (guint         id,
@@ -224,9 +201,6 @@ void            _clutter_id_to_color            (guint         id,
 ClutterActor *  _clutter_get_actor_by_id        (ClutterStage *stage,
                                                  guint32       actor_id);
 
-void            _clutter_set_sync_to_vblank     (gboolean      sync_to_vblank);
-gboolean        _clutter_get_sync_to_vblank     (void);
-
 /* use this function as the accumulator if you have a signal with
  * a G_TYPE_BOOLEAN return value; this will stop the emission as
  * soon as one handler returns TRUE
@@ -236,16 +210,7 @@ gboolean _clutter_boolean_handled_accumulator (GSignalInvocationHint *ihint,
                                                const GValue          *handler_return,
                                                gpointer               dummy);
 
-/* use this function as the accumulator if you have a signal with
- * a G_TYPE_BOOLEAN return value; this will stop the emission as
- * soon as one handler returns FALSE
- */
-gboolean _clutter_boolean_continue_accumulator (GSignalInvocationHint *ihint,
-                                                GValue                *return_accu,
-                                                const GValue          *handler_return,
-                                                gpointer               dummy);
-
-void _clutter_run_repaint_functions (ClutterRepaintFlags flags);
+void _clutter_run_repaint_functions (void);
 
 void _clutter_constraint_update_allocation (ClutterConstraint *constraint,
                                             ClutterActor      *actor,
@@ -260,52 +225,10 @@ void  _clutter_util_fully_transform_vertices (const CoglMatrix    *modelview,
                                               ClutterVertex       *vertices_out,
                                               int                  n_vertices);
 
-void _clutter_util_rectangle_union (const cairo_rectangle_int_t *src1,
-                                    const cairo_rectangle_int_t *src2,
-                                    cairo_rectangle_int_t       *dest);
-
-
-struct _ClutterVertex4
-{
-  float x;
-  float y;
-  float z;
-  float w;
-};
-
-void
-_clutter_util_vertex4_interpolate (const ClutterVertex4 *a,
-                                   const ClutterVertex4 *b,
-                                   double                progress,
-                                   ClutterVertex4       *res);
-
-#define CLUTTER_MATRIX_INIT_IDENTITY { \
-  1.0f, 0.0f, 0.0f, 0.0f, \
-  0.0f, 1.0f, 0.0f, 0.0f, \
-  0.0f, 0.0f, 1.0f, 0.0f, \
-  0.0f, 0.0f, 0.0f, 1.0f, \
-}
-
-float   _clutter_util_matrix_determinant        (const ClutterMatrix *matrix);
-
-void    _clutter_util_matrix_skew_xy            (ClutterMatrix *matrix,
-                                                 float          factor);
-void    _clutter_util_matrix_skew_xz            (ClutterMatrix *matrix,
-                                                 float          factor);
-void    _clutter_util_matrix_skew_yz            (ClutterMatrix *matrix,
-                                                 float          factor);
-
-gboolean        _clutter_util_matrix_decompose  (const ClutterMatrix *src,
-                                                 ClutterVertex       *scale_p,
-                                                 float                shear_p[3],
-                                                 ClutterVertex       *rotate_p,
-                                                 ClutterVertex       *translate_p,
-                                                 ClutterVertex4      *perspective_p);
-
 typedef struct _ClutterPlane
 {
-  float v0[3];
-  float n[3];
+  CoglVector3 v0;
+  CoglVector3 n;
 } ClutterPlane;
 
 typedef enum _ClutterCullResult
@@ -316,13 +239,6 @@ typedef enum _ClutterCullResult
   CLUTTER_CULL_RESULT_PARTIAL
 } ClutterCullResult;
 
-gboolean        _clutter_has_progress_function  (GType gtype);
-gboolean        _clutter_run_progress_function  (GType gtype,
-                                                 const GValue *initial,
-                                                 const GValue *final,
-                                                 gdouble progress,
-                                                 GValue *retval);
-
 G_END_DECLS
 
 #endif /* __CLUTTER_PRIVATE_H__ */
