@@ -1,17 +1,17 @@
 #ifndef __CLUTTER_STAGE_WINDOW_H__
 #define __CLUTTER_STAGE_WINDOW_H__
 
+#include <clutter/clutter-actor.h>
 #include <cogl/cogl.h>
-#include <clutter/clutter-types.h>
 
 G_BEGIN_DECLS
 
-#define CLUTTER_TYPE_STAGE_WINDOW               (_clutter_stage_window_get_type ())
+#define CLUTTER_TYPE_STAGE_WINDOW               (clutter_stage_window_get_type ())
 #define CLUTTER_STAGE_WINDOW(obj)               (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLUTTER_TYPE_STAGE_WINDOW, ClutterStageWindow))
 #define CLUTTER_IS_STAGE_WINDOW(obj)            (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLUTTER_TYPE_STAGE_WINDOW))
 #define CLUTTER_STAGE_WINDOW_GET_IFACE(obj)     (G_TYPE_INSTANCE_GET_INTERFACE ((obj), CLUTTER_TYPE_STAGE_WINDOW, ClutterStageWindowIface))
 
-/*
+/**
  * ClutterStageWindow: (skip)
  *
  * <structname>ClutterStageWindow</structname> is an opaque structure
@@ -22,7 +22,7 @@ G_BEGIN_DECLS
 typedef struct _ClutterStageWindow      ClutterStageWindow; /* dummy */
 typedef struct _ClutterStageWindowIface ClutterStageWindowIface;
 
-/*
+/**
  * ClutterStageWindowIface: (skip)
  *
  * The interface implemented by backends for stage windows
@@ -56,41 +56,24 @@ struct _ClutterStageWindowIface
                                                  gint                width,
                                                  gint                height);
   void              (* get_geometry)            (ClutterStageWindow *stage_window,
-                                                 cairo_rectangle_int_t *geometry);
+                                                 ClutterGeometry    *geometry);
 
-  void              (* schedule_update)         (ClutterStageWindow *stage_window,
-                                                 int                 sync_delay);
-  gint64            (* get_update_time)         (ClutterStageWindow *stage_window);
-  void              (* clear_update_time)       (ClutterStageWindow *stage_window);
-
-  void              (* add_redraw_clip)         (ClutterStageWindow    *stage_window,
-                                                 cairo_rectangle_int_t *stage_rectangle);
-  gboolean          (* has_redraw_clips)        (ClutterStageWindow    *stage_window);
-  gboolean          (* ignoring_redraw_clips)   (ClutterStageWindow    *stage_window);
-  gboolean          (* get_redraw_clip_bounds)  (ClutterStageWindow    *stage_window,
-                                                 cairo_rectangle_int_t *clip);
+  int               (* get_pending_swaps)       (ClutterStageWindow *stage_window);
 
+  void              (* add_redraw_clip)         (ClutterStageWindow *stage_window,
+                                                 ClutterGeometry    *stage_rectangle);
+  gboolean          (* has_redraw_clips)        (ClutterStageWindow *stage_window);
+  gboolean          (* ignoring_redraw_clips)   (ClutterStageWindow *stage_window);
 
   void              (* set_accept_focus)        (ClutterStageWindow *stage_window,
                                                  gboolean            accept_focus);
 
   void              (* redraw)                  (ClutterStageWindow *stage_window);
 
-  void              (* dirty_back_buffer)       (ClutterStageWindow *stage_window);
-
-  void              (* get_dirty_pixel)         (ClutterStageWindow *stage_window,
-                                                 int *x, int *y);
-
   CoglFramebuffer  *(* get_active_framebuffer)  (ClutterStageWindow *stage_window);
-
-  gboolean          (* can_clip_redraws)        (ClutterStageWindow *stage_window);
-
-  void              (* set_scale_factor)        (ClutterStageWindow *stage_window,
-                                                 int                 factor);
-  int               (* get_scale_factor)        (ClutterStageWindow *stage_window);
 };
 
-GType _clutter_stage_window_get_type (void) G_GNUC_CONST;
+GType clutter_stage_window_get_type (void) G_GNUC_CONST;
 
 ClutterActor *    _clutter_stage_window_get_wrapper        (ClutterStageWindow *window);
 
@@ -114,37 +97,21 @@ void              _clutter_stage_window_resize                  (ClutterStageWin
                                                                  gint                width,
                                                                  gint                height);
 void              _clutter_stage_window_get_geometry            (ClutterStageWindow *window,
-                                                                 cairo_rectangle_int_t *geometry);
-void              _clutter_stage_window_schedule_update         (ClutterStageWindow *window,
-                                                                 int                 sync_delay);
-gint64            _clutter_stage_window_get_update_time         (ClutterStageWindow *window);
-void              _clutter_stage_window_clear_update_time       (ClutterStageWindow *window);
+                                                                 ClutterGeometry    *geometry);
+int               _clutter_stage_window_get_pending_swaps       (ClutterStageWindow *window);
 
-void              _clutter_stage_window_add_redraw_clip         (ClutterStageWindow    *window,
-                                                                 cairo_rectangle_int_t *stage_clip);
-gboolean          _clutter_stage_window_has_redraw_clips        (ClutterStageWindow    *window);
-gboolean          _clutter_stage_window_ignoring_redraw_clips   (ClutterStageWindow    *window);
-gboolean          _clutter_stage_window_get_redraw_clip_bounds  (ClutterStageWindow    *window,
-                                                                 cairo_rectangle_int_t *clip);
+void              _clutter_stage_window_add_redraw_clip         (ClutterStageWindow *window,
+                                                                 ClutterGeometry    *stage_clip);
+gboolean          _clutter_stage_window_has_redraw_clips        (ClutterStageWindow *window);
+gboolean          _clutter_stage_window_ignoring_redraw_clips   (ClutterStageWindow *window);
 
 void              _clutter_stage_window_set_accept_focus        (ClutterStageWindow *window,
-                                                                 gboolean            accept_focus);
+                                                           gboolean            accept_focus);
 
 void              _clutter_stage_window_redraw                  (ClutterStageWindow *window);
 
-void              _clutter_stage_window_dirty_back_buffer       (ClutterStageWindow *window);
-
-void              _clutter_stage_window_get_dirty_pixel         (ClutterStageWindow *window,
-                                                                 int *x, int *y);
-
 CoglFramebuffer  *_clutter_stage_window_get_active_framebuffer  (ClutterStageWindow *window);
 
-gboolean          _clutter_stage_window_can_clip_redraws        (ClutterStageWindow *window);
-
-void              _clutter_stage_window_set_scale_factor        (ClutterStageWindow *window,
-                                                                 int                 factor);
-int               _clutter_stage_window_get_scale_factor        (ClutterStageWindow *window);
-
 G_END_DECLS
 
 #endif /* __CLUTTER_STAGE_WINDOW_H__ */
