@@ -262,6 +262,13 @@ void                  clutter_stage_set_accept_focus  (ClutterStage *stage,
                                                        gboolean      accept_focus);
 gboolean              clutter_stage_get_accept_focus  (ClutterStage *stage);
 
+
+void                  clutter_stage_set_motion_events_enabled (ClutterStage *stage,
+                                                               gboolean      enabled);
+gboolean              clutter_stage_get_motion_events_enabled (ClutterStage *stage);
+
+#ifndef CLUTTER_DISABLE_DEPRECATED
+
 /* Commodity macro, for mallum only */
 #define clutter_stage_add(stage,actor)                  G_STMT_START {  \
   if (CLUTTER_IS_STAGE ((stage)) && CLUTTER_IS_ACTOR ((actor)))         \
@@ -271,6 +278,8 @@ gboolean              clutter_stage_get_accept_focus  (ClutterStage *stage);
       clutter_container_add_actor (_container, _actor);                 \
     }                                                   } G_STMT_END
 
+#endif /* CLUTTER_DISABLE_DEPRECATED */
+
 G_END_DECLS
 
 #endif /* __CLUTTER_STAGE_H__ */
